@@ -42,9 +42,9 @@ private Q_SLOTS:
     void handleError( QNetworkReply::NetworkError );
 
 private:
-    void append( QString* input, const QString &key, const QString &value );
+    static void append( QString* input, const QString &key, const QString &value );
 
-    int maneuverType( int mapQuestId ) const;
+    static int maneuverType( int mapQuestId );
 
     GeoDataDocument* parse( const QByteArray &input ) const;
 
